=============
Meeting notes
=============

.. item:: MEETING-2019_01_01 Meeting minutes from review meeting 1 January 2019

    In this meeting we go over checklist items and answer their questions. The answers here have priority over the
    checkbox values in the PR description on GitHub.

.. checkbox-result:: QUE-UNIT_TESTS yes

.. checkbox-result:: QUE_MEETING-UNIQUE_NAME yes

.. checkbox-result:: QUE_MEETING-HW_EXECUTION no

.. item:: MOM_ACTION-81340_20200622_1_ACTION_1 Caption of action item

    Description of action item.

.. item-attributes-matrix:: Matrix of all checklist questions
    :filter: QUE(_MEETING)?-
    :attributes: checked
